@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2013-2022 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -31,6 +30,8 @@
 #include "qofonocallsettings.h"
 #include "qofonocallvolume.h"
 
+#include "qofonoipmultimediasystem.h"
+
 #include "qofonomessage.h"
 #include "qofonomessagemanager.h"
 #include "qofonomessagewaiting.h"
@@ -61,10 +62,14 @@
 #include "qofonolocationreporting.h"
 
 #include "qofononetworkoperatorlistmodel.h"
+#include "qofonosimlistmodel.h"
 
 void QOfonoDeclarativePlugin::registerTypes(const char *uri, int major, int minor)
 {
-    Q_ASSERT(QLatin1String(uri) == QLatin1String("MeeGo.QOfono"));
+    Q_ASSERT(QLatin1String(uri) == QLatin1String("MeeGo.QOfono") || QLatin1String(uri) == QLatin1String("QOfono"));
+    if (QLatin1String(uri) == QLatin1String("MeeGo.QOfono")) {
+        qWarning() << "MeeGo.QOfono QML module name is deprecated and subject for removal. Please adapt code to \"import QOfono\".";
+    }
 
     qmlRegisterType<QOfonoManager>(uri,major,minor,"OfonoManager");
     qmlRegisterType<QOfonoModem>(uri,major,minor,"OfonoModem");
@@ -83,6 +88,8 @@ void QOfonoDeclarativePlugin::registerTypes(const char *uri, int major, int mino
     qmlRegisterType<QOfonoCallSettings>(uri,major,minor,"OfonoCallSettings");
     qmlRegisterType<QOfonoCallMeter>(uri,major,minor,"OfonoCallMeter");
 
+    qmlRegisterType<QOfonoIpMultimediaSystem>(uri,major,minor,"OfonoIpMultimediaSystem");
+
     qmlRegisterType<QOfonoMessage>(uri,major,minor,"OfonoMessage");
     qmlRegisterType<QOfonoMessageManager>(uri,major,minor,"OfonoMessageManager");
     qmlRegisterType<QOfonoMessageWaiting>(uri,major,minor,"OfonoMessageWaiting");
@@ -111,18 +118,10 @@ void QOfonoDeclarativePlugin::registerTypes(const char *uri, int major, int mino
     qmlRegisterType<QOfonoLocationReporting>(uri,major,minor,"OfonoLocationReporting");
 
     qmlRegisterType<QOfonoNetworkOperatorListModel>(uri,major,minor,"OfonoNetworkOperatorListModel");
+    qmlRegisterType<QOfonoSimListModel>(uri,major,minor,"OfonoSimListModel");
 }
 
 void QOfonoDeclarativePlugin::registerTypes(const char *uri)
 {
     registerTypes(uri, 0, 2);
 }
-
-#if QT_VERSION < 0x050000
-void QOfonoDeclarativePlugin::initializeEngine(QDeclarativeEngine *engine, const char *uri)
-{
-    Q_UNUSED(uri);
-    Q_UNUSED(engine);
-}
-Q_EXPORT_PLUGIN2(ofonomodule, QT_PREPEND_NAMESPACE(QOfonoDeclarativePlugin))
-#endif
