@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2013-2020 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -13,8 +12,9 @@
 **
 ****************************************************************************/
 
+#include "dbustypes_p.h"
 #include "qofonocallsettings.h"
-#include "dbus/ofonocallsettings.h"
+#include "ofono_call_settings_interface.h"
 
 #define SUPER QOfonoModemInterface
 
@@ -34,7 +34,7 @@ void QOfonoCallSettings::connectOfono()
 
 QDBusAbstractInterface *QOfonoCallSettings::createDbusInterface(const QString &path)
 {
-    return new OfonoCallSettings("org.ofono", path, QDBusConnection::systemBus(), this);
+    return new OfonoCallSettings(OFONO_SERVICE, path, OFONO_BUS, this);
 }
 
 void QOfonoCallSettings::propertyChanged(const QString &property, const QVariant &value)
