@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2013-2022 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -13,8 +12,15 @@
 **
 ****************************************************************************/
 
+#include "dbustypes_p.h"
+#include "qofonoutils_p.h"
 #include "qofonoconnectionmanager.h"
-#include "dbus/ofonoconnectionmanager.h"
+#include "ofono_connection_manager_interface.h"
+
+typedef QWeakPointer<QOfonoConnectionManager> QOfonoConnectionManagerWeakPtr;
+typedef QSharedPointer<QOfonoConnectionManager> QOfonoConnectionManagerRef;
+typedef QMap<QString,QOfonoConnectionManagerWeakPtr> QOfonoConnectionManagerMap;
+Q_GLOBAL_STATIC(QOfonoConnectionManagerMap, ofonoConnectionManagerList)
 
 #define SUPER QOfonoModemInterface
 
@@ -24,6 +30,7 @@ public:
     bool initialized;
     QStringList contexts;
     QHash<QString,QString> contextTypes;
+    QString modemPath;
     QString filter;
 
     Private() : initialized(false) {}
@@ -46,13 +53,13 @@ void QOfonoConnectionManager::Private::filterContexts()
             QString f(filter);
             f.remove(' ').remove('\t');
             if (f[0] == '!') {
-                QStringList blackList = f.remove(0,1).split(',', QString::SkipEmptyParts);
+                QStringList blackList = f.remove(0,1).split(',', QOfonoSkipEmptyParts);
                 foreach (QString path, contextList) {
                     if (!blackList.contains(contextTypes.value(path)))
                         contexts.append(path);
                 }
             } else {
-                QStringList whiteList = f.split(',', QString::SkipEmptyParts);
+                QStringList whiteList = f.split(',', QOfonoSkipEmptyParts);
                 foreach (QString path, contextList) {
                     if (whiteList.contains(contextTypes.value(path)))
                         contexts.append(path);
@@ -79,7 +86,7 @@ bool QOfonoConnectionManager::isValid() const
 
 QDBusAbstractInterface *QOfonoConnectionManager::createDbusInterface(const QString &path)
 {
-    OfonoConnectionManager* iface = new OfonoConnectionManager("org.ofono", path, QDBusConnection::systemBus(), this);
+    OfonoConnectionManager* iface = new OfonoConnectionManager(OFONO_SERVICE, path, OFONO_BUS, this);
     connect(new QDBusPendingCallWatcher(iface->GetContexts(), iface),
         SIGNAL(finished(QDBusPendingCallWatcher*)),
         SLOT(onGetContextsFinished(QDBusPendingCallWatcher*)));
@@ -137,6 +144,17 @@ void QOfonoConnectionManager::removeContext(const QString &path)
     }
 }
 
+void QOfonoConnectionManager::resetContexts() // Since 0.110
+{
+    OfonoConnectionManager *iface = (OfonoConnectionManager*)dbusInterface();
+    if (iface) {
+        connect(new QDBusPendingCallWatcher(
+            iface->DeactivateAll(), iface),
+            SIGNAL(finished(QDBusPendingCallWatcher*)),
+            SLOT(onDeactivateAllFinished(QDBusPendingCallWatcher*)));
+    }
+}
+
 bool QOfonoConnectionManager::attached() const
 {
     return getBool("Attached");
@@ -283,6 +301,34 @@ void QOfonoConnectionManager::onRemoveContextFinished(QDBusPendingCallWatcher *w
     }
 }
 
+void QOfonoConnectionManager::onDeactivateAllFinished(QDBusPendingCallWatcher *watch)
+{
+    watch->deleteLater();
+    QDBusPendingReply<> reply(*watch);
+    if (reply.isError()) {
+        qDebug() << reply.error();
+        Q_EMIT reportError(reply.error().message());
+    } else {
+        OfonoConnectionManager *iface = (OfonoConnectionManager*)dbusInterface();
+        if (iface) {
+            connect(new QDBusPendingCallWatcher(
+                iface->ResetContexts(), iface),
+                SIGNAL(finished(QDBusPendingCallWatcher*)),
+                SLOT(onResetContextFinished(QDBusPendingCallWatcher*)));
+        }
+    }
+}
+
+void QOfonoConnectionManager::onResetContextFinished(QDBusPendingCallWatcher *watch)
+{
+    watch->deleteLater();
+    QDBusPendingReply<> reply(*watch);
+    if (reply.isError()) {
+        qDebug() << reply.error();
+        Q_EMIT reportError(reply.error().message());
+    }
+}
+
 QString QOfonoConnectionManager::modemPath() const
 {
     return SUPER::modemPath();
@@ -297,3 +343,15 @@ QOfonoConnectionManager::Private *QOfonoConnectionManager::privateData() const
 {
     return (QOfonoConnectionManager::Private*)SUPER::extData();
 }
+
+QSharedPointer<QOfonoConnectionManager>
+QOfonoConnectionManager::instance(const QString &path)
+{
+    QOfonoConnectionManagerRef mgr = ofonoConnectionManagerList()->value(path);
+    if (mgr.isNull()) {
+        mgr = QOfonoConnectionManagerRef::create();
+        mgr->fixObjectPath(path);
+        ofonoConnectionManagerList()->insert(path, mgr);
+    }
+    return mgr;
+}
