@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2013-2020 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -13,8 +12,9 @@
 **
 ****************************************************************************/
 
+#include "dbustypes_p.h"
 #include "qofonomessagewaiting.h"
-#include "dbus/ofonomessagewaiting.h"
+#include "ofono_messagewaiting_interface.h"
 
 #define SUPER QOfonoModemInterface
 
@@ -29,7 +29,7 @@ QOfonoMessageWaiting::~QOfonoMessageWaiting()
 
 QDBusAbstractInterface *QOfonoMessageWaiting::createDbusInterface(const QString &path)
 {
-    return new OfonoMessageWaiting("org.ofono", path, QDBusConnection::systemBus(), this);
+    return new OfonoMessageWaiting(OFONO_SERVICE, path, OFONO_BUS, this);
 }
 
 void QOfonoMessageWaiting::connectOfono()
