@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2014-2015 Jolla Ltd.
-** Contact: slava.monich@jolla.com
+** Copyright (C) 2014-2020 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -16,6 +15,11 @@
 #include "qofonoobject.h"
 #include "qofonoutils_p.h"
 
+namespace {
+    const QString GET_PROPERTIES("GetProperties");
+    const QString SET_PROPERTY("SetProperty");
+}
+
 class QOfonoObject::Private
 {
 public:
@@ -23,14 +27,22 @@ public:
     QDBusAbstractInterface *interface;
     bool initialized;
     bool fixedPath;
+    bool validMark;
+    int validMarkCount;
     QString objectPath;
     QVariantMap properties;
 
     Private(QOfonoObject::ExtData *data) : ext(data),
-        interface(NULL), initialized(false), fixedPath(false) {}
+        interface(Q_NULLPTR), initialized(false), fixedPath(false),
+        validMark(false), validMarkCount(0) {}
     ~Private() { delete ext; }
 
     QDBusPendingCall setProperty(const QString &key, const QVariant &value);
+    void getProperties(QOfonoObject *obj);
+
+    bool dropDbusInterface();
+    void setDbusInterface(QOfonoObject *obj, QDBusAbstractInterface *iface);
+    static void applyProperties(QOfonoObject *obj, const QVariantMap &properties);
 
     class SetPropertyWatcher : public QDBusPendingCallWatcher {
     public:
@@ -45,24 +57,81 @@ QOfonoObject::ExtData::~ExtData()
 {
 }
 
+QOfonoObject::ValidTracker::ValidTracker(QOfonoObject* obj) : object(obj)
+{
+    if (!(object->d_ptr->validMarkCount++)) {
+        object->d_ptr->validMark = obj->isValid();
+    }
+}
+
+QOfonoObject::ValidTracker::~ValidTracker()
+{
+    if (!(--object->d_ptr->validMarkCount)) {
+        const bool valid = object->isValid();
+        if (object->d_ptr->validMark != valid) {
+            Q_EMIT object->validChanged(valid);
+        }
+    }
+}
+
 QDBusPendingCall QOfonoObject::Private::setProperty(const QString &key, const QVariant &value)
 {
     // Caller checks interface for NULL
     QVariantList args;
     args << QVariant(key) << QVariant::fromValue(QDBusVariant(value));
-    return interface->asyncCallWithArgumentList("SetProperty", args);
+    return interface->asyncCallWithArgumentList(SET_PROPERTY, args);
 }
 
+void QOfonoObject::Private::getProperties(QOfonoObject *obj)
+{
+    QObject::connect(new QDBusPendingCallWatcher(
+        interface->asyncCall(GET_PROPERTIES), interface),
+        SIGNAL(finished(QDBusPendingCallWatcher*)), obj,
+        SLOT(onGetPropertiesFinished(QDBusPendingCallWatcher*)));
+}
+
+bool QOfonoObject::Private::dropDbusInterface()
+{
+    if (interface) {
+        delete interface;
+        interface = Q_NULLPTR;
+        return true;
+    }
+    return false;
+}
+
+void QOfonoObject::Private::setDbusInterface(QOfonoObject *obj, QDBusAbstractInterface *iface)
+{
+    interface = iface;
+    connect(iface, SIGNAL(PropertyChanged(QString,QDBusVariant)), obj,
+        SLOT(onPropertyChanged(QString,QDBusVariant)));
+}
+
+void QOfonoObject::Private::applyProperties(QOfonoObject *obj, const QVariantMap &props)
+{
+    for (QVariantMap::ConstIterator it = props.constBegin(); it != props.constEnd(); ++it) {
+        obj->updateProperty(it.key(), it.value());
+    }
+}
 
 QOfonoObject::QOfonoObject(QObject *parent) :
     QObject(parent),
-    d_ptr(new QOfonoObject::Private(NULL))
+    d_ptr(new Private(Q_NULLPTR))
 {
 }
 
-QOfonoObject::QOfonoObject(QOfonoObject::ExtData *ext, QObject *parent) :
+QOfonoObject::QOfonoObject(ExtData *ext, const QString &path, QObject *parent) :
     QObject(parent),
-    d_ptr(new QOfonoObject::Private(ext))
+    d_ptr(new Private(ext))
+{
+    // Just set the path... This constructor is used by the objects which
+    // initialize themselves synchronously by calling setDbusInterfaceSync()
+    d_ptr->objectPath = path;
+}
+
+QOfonoObject::QOfonoObject(ExtData *ext, QObject *parent) :
+    QObject(parent),
+    d_ptr(new Private(ext))
 {
 }
 
@@ -71,7 +140,7 @@ QOfonoObject::~QOfonoObject()
     delete d_ptr;
 }
 
-QOfonoObject::ExtData* QOfonoObject::extData() const
+QOfonoObject::ExtData *QOfonoObject::extData() const
 {
     return d_ptr->ext;
 }
@@ -100,7 +169,10 @@ void QOfonoObject::fixObjectPath(const QString &path)
     } else if (d_ptr->objectPath != path) {
         d_ptr->objectPath = path;
         d_ptr->fixedPath = true;
-        objectPathChanged(path, NULL);
+        objectPathChanged(path, Q_NULLPTR);
+    } else {
+        // Still mark it as fixed
+        d_ptr->fixedPath = true;
     }
 }
 
@@ -119,48 +191,68 @@ QDBusAbstractInterface *QOfonoObject::dbusInterface() const
     return d_ptr->interface;
 }
 
-void QOfonoObject::resetDbusInterface(const QVariantMap *properties)
+bool QOfonoObject::getPropertiesSync() // Since 1.0.101
 {
-    setDbusInterface(d_ptr->objectPath.isEmpty() ? NULL :
-        createDbusInterface(d_ptr->objectPath), properties);
+    if (d_ptr->interface) {
+        // Synchronous call
+        ValidTracker valid(this);
+        QDBusPendingReply<QVariantMap> reply(d_ptr->interface->call(GET_PROPERTIES));
+        if (reply.isError()) {
+            qWarning() << reply.error();
+        } else {
+            const QVariantMap properties(reply.value());
+            Private::applyProperties(this, properties);
+            d_ptr->initialized = true;
+            return true;
+        }
+    }
+    return false;
+}
+
+void QOfonoObject::setDbusInterfaceSync(QDBusAbstractInterface *iface) // Since 1.0.101
+{
+    ValidTracker valid(this);
+    d_ptr->initialized = false;
+    if (d_ptr->dropDbusInterface()) {
+        dbusInterfaceDropped();
+    }
+    if (iface) {
+        d_ptr->setDbusInterface(this, iface);
+        getPropertiesSync();
+    }
+}
+
+void QOfonoObject::resetDbusInterfaceSync() // Since 1.0.101
+{
+    setDbusInterfaceSync(d_ptr->objectPath.isEmpty() ? Q_NULLPTR :
+        createDbusInterface(d_ptr->objectPath));
 }
 
 void QOfonoObject::setDbusInterface(QDBusAbstractInterface *iface, const QVariantMap *properties)
 {
-    bool wasValid = isValid();
+    ValidTracker valid(this);
     d_ptr->initialized = false;
-    if (d_ptr->interface) {
-        delete d_ptr->interface;
-        d_ptr->interface = NULL;
+    if (d_ptr->dropDbusInterface()) {
         dbusInterfaceDropped();
     }
     if (iface) {
-        d_ptr->interface = iface;
+        d_ptr->setDbusInterface(this, iface);
         if (properties) {
+            Private::applyProperties(this, *properties);
             d_ptr->initialized = true;
-            // Ofono objects have fixed sets of properties, there's no need to check
-            // for disappearance or reappearance of individual properties.
-            for (QVariantMap::ConstIterator it = properties->constBegin();
-                it != properties->constEnd(); ++it) {
-                updateProperty(it.key(), it.value());
-            }
         } else {
             d_ptr->initialized = false;
-            connect(new QDBusPendingCallWatcher(
-                iface->asyncCall("GetProperties"), iface),
-                SIGNAL(finished(QDBusPendingCallWatcher*)),
-                SLOT(onGetPropertiesFinished(QDBusPendingCallWatcher*)));
+            d_ptr->getProperties(this);
         }
-        connect(iface,
-            SIGNAL(PropertyChanged(QString,QDBusVariant)),
-            SLOT(onPropertyChanged(QString,QDBusVariant)));
-    }
-    bool valid = isValid();
-    if (valid != wasValid) {
-        Q_EMIT validChanged(valid);
     }
 }
 
+void QOfonoObject::resetDbusInterface(const QVariantMap *properties)
+{
+    setDbusInterface(d_ptr->objectPath.isEmpty() ? Q_NULLPTR :
+        createDbusInterface(d_ptr->objectPath), properties);
+}
+
 void QOfonoObject::dbusInterfaceDropped()
 {
     if (!d_ptr->properties.isEmpty()) {
@@ -176,7 +268,7 @@ void QOfonoObject::onGetPropertiesFinished(QDBusPendingCallWatcher *watch)
     watch->deleteLater();
     QDBusPendingReply<QVariantMap> reply(*watch);
     if (!reply.isError()) {
-        getPropertiesFinished(reply.value(), NULL);
+        getPropertiesFinished(reply.value(), Q_NULLPTR);
     } else {
         QDBusError error = reply.error();
         getPropertiesFinished(QVariantMap(), &error);
@@ -186,16 +278,17 @@ void QOfonoObject::onGetPropertiesFinished(QDBusPendingCallWatcher *watch)
 void QOfonoObject::getPropertiesFinished(const QVariantMap &properties, const QDBusError *error)
 {
     if (!error) {
-        for (QVariantMap::ConstIterator it = properties.constBegin();
-             it != properties.constEnd(); ++it) {
-            updateProperty(it.key(), it.value());
-        }
+        ValidTracker valid(this);
+        Private::applyProperties(this, properties);
         d_ptr->initialized = true;
-        if (isValid()) {
-            Q_EMIT validChanged(true);
-        }
+    } else if (qofono::isTimeout(*error)) {
+        // Retry GetProperties call if it times out
+        qDebug() << "Retrying"
+                 << qPrintable(d_ptr->interface->interface() + ".GetProperties")
+                 << d_ptr->interface->path();
+        d_ptr->getProperties(this);
     } else {
-        qDebug() << *error;
+        qWarning() << *error;
         Q_EMIT reportError(error->message());
     }
 }
@@ -262,6 +355,13 @@ bool QOfonoObject::setPropertySync(const QString &key, const QVariant &value)
     }
 }
 
+void QOfonoObject::queryProperties()
+{
+    if (d_ptr->interface) {
+        d_ptr->getProperties(this);
+    }
+}
+
 void QOfonoObject::setProperty(const QString &key, const QVariant &value)
 {
     if (d_ptr->interface) {
@@ -279,7 +379,7 @@ void QOfonoObject::onSetPropertyFinished(QDBusPendingCallWatcher *watch)
     QDBusError dbusError;
     const QDBusError *error;
     if (!reply.isError()) {
-        error = NULL;
+        error = Q_NULLPTR;
     } else {
         dbusError = reply.error();
         error = &dbusError;
