@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2013-2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2013-2020 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -13,8 +12,9 @@
 **
 ****************************************************************************/
 
+#include "dbustypes_p.h"
 #include "qofonoradiosettings.h"
-#include "dbus/ofonoradiosettings.h"
+#include "ofono_radio_settings_interface.h"
 
 #define SUPER QOfonoModemInterface
 
@@ -29,7 +29,7 @@ QOfonoRadioSettings::~QOfonoRadioSettings()
 
 QDBusAbstractInterface *QOfonoRadioSettings::createDbusInterface(const QString &path)
 {
-    return new OfonoRadioSettings("org.ofono", path, QDBusConnection::systemBus(), this);
+    return new OfonoRadioSettings(OFONO_SERVICE, path, OFONO_BUS, this);
 }
 
 void QOfonoRadioSettings::setModemPath(const QString &path)
@@ -47,6 +47,8 @@ void QOfonoRadioSettings::propertyChanged(const QString &property, const QVarian
     SUPER::propertyChanged(property, value);
     if (property == QLatin1String("TechnologyPreference")) {
         Q_EMIT technologyPreferenceChanged(value.value<QString>());
+    } else if (property == QLatin1String("AvailableTechnologies")) {
+        Q_EMIT availableTechnologiesChanged(value.value<QStringList>());
     } else if (property == QLatin1String("GsmBand")) {
         Q_EMIT gsmBandChanged(value.value<QString>());
     } else if (property == QLatin1String("UtmsBand")) {
@@ -66,6 +68,11 @@ void QOfonoRadioSettings::setTechnologyPreference(const QString &preference)
     setProperty("TechnologyPreference",  preference);
 }
 
+QStringList QOfonoRadioSettings::availableTechnologies() const
+{
+    return getStringList("AvailableTechnologies");
+}
+
 QString QOfonoRadioSettings::gsmBand() const
 {
     return getString("GsmBand");
