@@ -1,7 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Jolla Ltd.
-** Contact: lorn.potter@jollamobile.com
+** Copyright (C) 2014-2022 Jolla Ltd.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -18,6 +17,12 @@
 
 #include "qofono_global.h"
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+#  define QOfonoSkipEmptyParts Qt::SkipEmptyParts
+#else
+#  define QOfonoSkipEmptyParts QString::SkipEmptyParts
+#endif
+
 namespace qofono {
 
 /* Carefully compare variant values, handling invalid and null values properly.
@@ -36,6 +41,18 @@ inline bool safeVariantEq(const QVariant &v1, const QVariant &v2)
     return v1 == v2;
 }
 
+inline bool isTimeout(const QDBusError &error)
+{
+    switch (error.type()) {
+    case QDBusError::NoReply:
+    case QDBusError::Timeout:
+    case QDBusError::TimedOut:
+        return true;
+    default:
+        return false;
+    }
+}
+
 }
 
 #endif // QOFONOUTILS_P_H
